@@ -999,8 +999,6 @@ static string lua_createReverse(const string &format, boost::optional<opts_t> ex
       return {"unknown"};
     }
 
-    vector<ComboAddress> candidates;
-
     // so, query comes in for 4.3.2.1.in-addr.arpa, zone is called 2.1.in-addr.arpa
     // exceptions["1.2.3.4"]="bert.powerdns.com" then provides an exception
     if (exceptions) {
@@ -1028,7 +1026,10 @@ static string lua_createReverse(const string &format, boost::optional<opts_t> ex
     return fmt.str();
   }
   catch(std::exception& ex) {
-    g_log<<Logger::Error<<"error: "<<ex.what()<<endl;
+    g_log<<Logger::Error<<"createReverse error: "<<ex.what()<<endl;
+  }
+  catch (const PDNSException &e) {
+    g_log<<Logger::Error<<"createReverse error: "<<e.reason<<endl;
   }
   return {"error"};
 }
@@ -1153,8 +1154,6 @@ static string lua_createForward6()
 
 static string lua_createReverse6(const string &format, boost::optional<opts_t> exceptions)
 {
-  vector<ComboAddress> candidates;
-
   try {
     auto labels= s_lua_record_ctx->qname.getRawLabels();
     if (labels.size()<32) {
@@ -1214,12 +1213,12 @@ static string lua_createReverse6(const string &format, boost::optional<opts_t> e
     return fmt.str();
   }
   catch(std::exception& ex) {
-    g_log<<Logger::Error<<"Lua record exception: "<<ex.what()<<endl;
+    g_log<<Logger::Error<<"createReverse6 exception: "<<ex.what()<<endl;
   }
   catch(PDNSException& ex) {
-    g_log<<Logger::Error<<"Lua record exception: "<<ex.reason<<endl;
+    g_log<<Logger::Error<<"createReverse6 exception: "<<ex.reason<<endl;
   }
-  return {"unknown"};
+  return {"error"};
 }
 
 static vector<string> lua_filterForward(const string& address, NetmaskGroup& nmg, boost::optional<string> fallback)
